# cherv-say-python
## Описание
Аналог CowSay, только вместо коровы - червяк.
## Установка и использование
### Установка:
```bash
pip install cherv
```
### Использование:
```bash
python -m cherv [your message]
```
### Команды:
```bash
python -m cherv --help  # выводит справку по использованию
```
## Скриншоты:
![cherv_screenshot](https://github.com/AyaalTech/wormsay-python/assets/80465121/9503a4f2-a4f5-4382-8a15-6677f38f3a2f)

